@@ -44,7 +44,7 @@ iptables -t raw -N "${aembit_raw_output_chain_name}"
 #
 # See https://www.frozentux.net/iptables-tutorial/iptables-tutorial.html#STATEMACHINE
 # for more information on conntrack.
-# iptables -t raw -A "${aembit_raw_output_chain_name}" -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
+iptables -t raw -A "${aembit_raw_output_chain_name}" -p udp --dport 53 -m owner --gid-owner "${aembit_group_id}" -j NOTRACK
 
 # The story for this rule is extremely similar to the above (only occurring in the VM environment).
 #
@@ -57,7 +57,7 @@ iptables -t raw -N "${aembit_raw_output_chain_name}"
 # resolved port), and this packet is unreachable.
 #
 # As a result, we are adding this rule to make sure that traffic from ResolveD is not NATed.
-# iptables -t raw -A "${aembit_raw_output_chain_name}" -p udp -s 127.0.0.53 --sport 53 -j NOTRACK
+iptables -t raw -A "${aembit_raw_output_chain_name}" -p udp -s 127.0.0.53 --sport 53 -j NOTRACK
 
 # Add chain
 iptables -t raw -A OUTPUT -j "${aembit_raw_output_chain_name}"
@@ -65,7 +65,7 @@ iptables -t raw -A OUTPUT -j "${aembit_raw_output_chain_name}"
 # ----- aembit_raw_prerouting_chain -----
 
 iptables -t raw -N "${aembit_raw_prerouting_chain_name}"
-# iptables -t raw -A "${aembit_raw_prerouting_chain_name}" -p udp --sport 53 -j NOTRACK
+iptables -t raw -A "${aembit_raw_prerouting_chain_name}" -p udp --sport 53 -j NOTRACK
 iptables -t raw -A PREROUTING -j "${aembit_raw_prerouting_chain_name}"
 
 # ----- aembit_nat_output_chain ------
@@ -74,7 +74,7 @@ iptables -t raw -A PREROUTING -j "${aembit_raw_prerouting_chain_name}"
 iptables -t nat -N "${aembit_nat_output_chain_name}"
 
 # Ignore all packets from the Agent Proxy
-iptables -t nat -A "${aembit_nat_output_chain_name}" -m owner --gid-owner "${aembit_group_id}" -j RETURN
+iptables -t nat -A "${aembit_nat_output_chain_name}" -m owner --gid-owner "${aembit_group_id}" --suppl-groups -j RETURN
 
 # Ignore TCP loopback
 iptables -t nat -A "${aembit_nat_output_chain_name}" -p tcp -o lo -j RETURN
@@ -93,9 +93,9 @@ iptables -t nat -A "${aembit_nat_output_chain_name}" -p tcp --syn -j REDIRECT --
 # Redirect DNS traffic to agent proxy DNS port, except for outbound traffic from systemd-resolved.
 resolve_d_user_id=$(id --user systemd-resolve);
 if [ -n "${resolve_d_user_id}" ]; then
-    # iptables -t nat -A "${aembit_nat_output_chain_name}" -p udp --dport 53 -m owner --uid-owner "${resolve_d_user_id}" -j RETURN
+    iptables -t nat -A "${aembit_nat_output_chain_name}" -p udp --dport 53 -m owner --uid-owner "${resolve_d_user_id}" -j RETURN
 fi
-# iptables -t nat -A "${aembit_nat_output_chain_name}" -p udp --dport 53 -j REDIRECT --to "${agent_dns_port}"
+iptables -t nat -A "${aembit_nat_output_chain_name}" -p udp --dport 53 -j REDIRECT --to "${agent_dns_port}"
 
 # Add chain
 iptables -t nat -A OUTPUT -j "${aembit_nat_output_chain_name}"
